Bug#984180: Patch to fix FTBFS with GCC-11

2021-09-27 Thread Slávek Banko
+ patch

Hi Debian BTS, Matthias,

the problem seems only to use the name 'byte' for the 'usigned char' data 
type. The attached patch changes the name to 'byte_t' instead of 'byte', 
thereby resolving the problem.

Cheers
-- 
Slávek
Index: b/htword/WordDBPage.cc
===
--- a/htword/WordDBPage.cc
+++ b/htword/WordDBPage.cc
@@ -155,7 +155,7 @@
 	Uncompress_main(pin);
 	break;
 case CMPRTYPE_BADCOMPRESS:// this page did not compress correctly
-	pin->get_zone((byte *)pg,pgsz*8,"INITIALBUFFER");
+	pin->get_zone((byte_t *)pg,pgsz*8,"INITIALBUFFER");
 	break;
 default:
 	errr("WordDBPage::Uncompress: CMPRTYPE incoherent");
@@ -181,7 +181,7 @@
 int *rnum_sizes=new int[nnums];
 CHECK_MEM(rnum_sizes);
 // char differences between words
-byte *rworddiffs=NULL;
+byte_t *rworddiffs=NULL;
 int nrworddiffs;
 
 // *** read header
@@ -288,7 +288,7 @@
 return OK;
 }
 void 
-WordDBPage::Uncompress_rebuild(unsigned int **rnums,int *rnum_sizes,int nnums0,byte *rworddiffs,int nrworddiffs)
+WordDBPage::Uncompress_rebuild(unsigned int **rnums,int *rnum_sizes,int nnums0,byte_t *rworddiffs,int nrworddiffs)
 {
 int irwordiffs=0;
 int nfields=WordKey::NFields();
@@ -405,7 +405,7 @@
 
 // display
 void 
-WordDBPage::Uncompress_show_rebuild(unsigned int **rnums,int *rnum_sizes,int nnums0,byte *rworddiffs,int nrworddiffs)
+WordDBPage::Uncompress_show_rebuild(unsigned int **rnums,int *rnum_sizes,int nnum

Bug#849339: Please fix xcolorsel on hppa Linux arch

2021-09-27 Thread Helge Deller
alternatively, this patch works too.
Please apply.
THX, Helgediff -up ./Imakefile.org ./Imakefile
--- ./Imakefile.org	2021-09-27 19:22:53.976568137 +
+++ ./Imakefile	2021-09-27 19:27:11.670928299 +
@@ -49,7 +49,7 @@
 
 /* Please add any preprocessor defines in config.h */
 
-#ifdef HPArchitecture
+#if defined(HPArchitecture) && !defined(__linux__)
 CCOPTIONS = -Aa -D_HPUX_SOURCE
 #endif
 


Bug#995211: libbrahe: reproducible-builds: Example Makefiles embed build paths and binary paths

2021-09-27 Thread Vagrant Cascadian
Source: libbrahe
Severity: normal
Tags: patch
User: reproducible-bui...@lists.alioth.debian.org
Usertags: buildpath usrmerge shell
X-Debbugs-Cc: reproducible-b...@lists.alioth.debian.org

The build path and several binary paths are embedded in example Makefiles
shipped in the package:

  
https://tests.reproducible-builds.org/debian/rb-pkg/unstable/amd64/diffoscope-results/libbrahe.html

  /usr/share/doc/libbrahe-dev/test/Makefile.gz

  EGREP·=·/bin/grep·-E
  vs.
  EGREP·=·/usr/bin/grep·-E

  abs_builddir·=·/build/1st/libbrahe-1.3.2/test
  vs.
  abs_builddir·=·/build/2/libbrahe-1.3.2/2nd/test

Since these values may differ with the installed system, in order to use
the example Makefile, a person would have to regenerate it from
Makefile.in, which is also provided in the package.

The attached patch excludes Makefile from getting installed in
debian/libbrahe-dev.install.

With this patch applied libbrahe should become reproducible on
tests.reproducible-builds.org.

Thanks for maintaining libbrahe!

live well,
  vagrant
From 1cbf6e4d300b0c3ffeb8986ca14ffb240e4f3c51 Mon Sep 17 00:00:00 2001
From: Vagrant Cascadian 
Date: Mon, 27 Sep 2021 21:59:55 +
Subject: [PATCH 1/8] libbrahe-dev: Do not install test Makefile.

The Makefile contains build paths and binary paths specific to the
build environment, and would need to be regenerated from Makefile.am
or Makefile.in in order to use them on another system.
---
 debian/libbrahe-dev.install | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/debian/libbrahe-dev.install b/debian/libbrahe-dev.install
index b882b80..28ea15b 100644
--- a/debian/libbrahe-dev.install
+++ b/debian/libbrahe-dev.install
@@ -3,4 +3,4 @@ debian/tmp/usr/lib/*/lib*.a
 debian/tmp/usr/lib/*/lib*.so
 debian/tmp/usr/lib/*/*.la
 test/*.c usr/share/doc/libbrahe-dev/test
-test/Makefile* usr/share/doc/libbrahe-dev/test
+test/Makefile.* usr/share/doc/libbrahe-dev/test
-- 
2.30.2



signature.asc
Description: PGP signature


Bug#995211: marked as done (libbrahe: reproducible-builds: Example Makefiles embed build paths and binary paths)

2021-09-27 Thread Debian Bug Tracking System
Your message dated Tue, 28 Sep 2021 00:03:23 +
with message-id 
and subject line Bug#995211: fixed in libbrahe 1.3.2-9
has caused the Debian Bug report #995211,
regarding libbrahe: reproducible-builds: Example Makefiles embed build paths 
and binary paths
to be marked as done.

This means that you claim that the problem has been dealt with.
If this is not the case it is now your responsibility to reopen the
Bug report if necessary, and/or fix the problem forthwith.

(NB: If you are a system administrator and have no idea what this
message is talking about, this may indicate a serious mail system
misconfiguration somewhere. Please contact ow...@bugs.debian.org
immediately.)


-- 
995211: https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=995211
Debian Bug Tracking System
Contact ow...@bugs.debian.org with problems
--- Begin Message ---
Source: libbrahe
Severity: normal
Tags: patch
User: reproducible-bui...@lists.alioth.debian.org
Usertags: buildpath usrmerge shell
X-Debbugs-Cc: reproducible-b...@lists.alioth.debian.org

The build path and several binary paths are embedded in example Makefiles
shipped in the package:

  
https://tests.reproducible-builds.org/debian/rb-pkg/unstable/amd64/diffoscope-results/libbrahe.html

  /usr/share/doc/libbrahe-dev/test/Makefile.gz

  EGREP·=·/bin/grep·-E
  vs.
  EGREP·=·/usr/bin/grep·-E

  abs_builddir·=·/build/1st/libbrahe-1.3.2/test
  vs.
  abs_builddir·=·/build/2/libbrahe-1.3.2/2nd/test

Since these values may differ with the installed system, in order to use
the example Makefile, a person would have to regenerate it from
Makefile.in, which is also provided in the package.

The attached patch excludes Makefile from getting installed in
debian/libbrahe-dev.install.

With this patch applied libbrahe should become reproducible on
tests.reproducible-builds.org.

Thanks for maintaining libbrahe!

live well,
  vagrant
From 1cbf6e4d300b0c3ffeb8986ca14ffb240e4f3c51 Mon Sep 17 00:00:00 2001
From: Vagrant Cascadian 
Date: Mon, 27 Sep 2021 21:59:55 +
Subject: [PATCH 1/8] libbrahe-dev: Do not install test Makefile.

The Makefile contains build paths and binary paths specific to the
build environment, and would need to be regenerated from Makefile.am
or Makefile.in in order to use them on another system.
---
 debian/libbrahe-dev.install | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/debian/libbrahe-dev.install b/debian/libbrahe-dev.install
index b882b80..28ea15b 100644
--- a/debian/libbrahe-dev.install
+++ b/debian/libbrahe-dev.install
@@ -3,4 +3,4 @@ debian/tmp/usr/lib/*/lib*.a
 debian/tmp/usr/lib/*/lib*.so
 debian/tmp/usr/lib/*/*.la
 test/*.c usr/share/doc/libbrahe-dev/test
-test/Makefile* usr/share/doc/libbrahe-dev/test
+test/Makefile.* usr/share/doc/libbrahe-dev/test
-- 
2.30.2



signature.asc
Description: PGP signature
--- End Message ---
--- Begin Message ---
Source: libbrahe
Source-Version: 1.3.2-9
Done: Vagrant Cascadian 

We believe that the bug you reported is fixed in the latest version of
libbrahe, which is due to be installed in the Debian FTP archive.

A summary of the changes between this version and the previous one is
attached.

Thank you for reporting the bug, which will now be closed.  If you
have further comments please address them to 995...@bugs.debian.org,
and the maintainer will reopen the bug report if appropriate.

Debian distribution maintenance software
pp.
Vagrant Cascadian  (supplier of updated libbrahe package)

(This message was generated automatically at their request; if you
believe that there is a problem with it please contact the archive
administrators by mailing ftpmas...@ftp-master.debian.org)


-BEGIN PGP SIGNED MESSAGE-
Hash: SHA512

Format: 1.8
Date: Mon, 27 Sep 2021 16:29:23 -0700
Source: libbrahe
Architecture: source
Version: 1.3.2-9
Distribution: unstable
Urgency: medium
Maintainer: Debian QA Group 
Changed-By: Vagrant Cascadian 
Closes: 995211
Changes:
 libbrahe (1.3.2-9) unstable; urgency=medium
 .
   * QA upload.
   * libbrahe-dev: Do not install test Makefile (Closes: #995211).
   * debian/control: Update Vcs-Browser and Vcs-Git.
   * debian/control: Set Rules-Requires-Root to "no".
   * debian/changelog: Delete trailing whitespace.
   * debian/rules: Delete boilerplate comments.
   * debian/control: Update to debhelper-compat 13.
   * debian/rules: Add override for dh_missing to only list missing files.
   * debian/control: Delete trailing whitespace.
   * debian/control: Split Build-Depends into multiple lines.
   * Remove Dependency on dh-autoreconf and explicit call to autoreconf in
 debian/rules.
   * debian/control: Drop Build-Depends on autotools-dev.
   * debian/control: Remove quilt from Build-Depends.
   * debian/control: Update Standards-Version to 4.6.0.
   * debian/control: Mark libbrahe-1.3-3 as Multi-Arch: same.
Checksums-Sha1:
 ce1e16c73ce2773f06f76ed20b8d5fcd63446947 1475 libbrahe_1.3.2-9.dsc
 6a0aeccf3df3817a293ff805bc3f4fdef50fdd37 4252 libbrahe_1.3.2-9.debian.tar.xz
Checksum

slcfitsio is marked for autoremoval from testing

2021-09-27 Thread Debian testing autoremoval watch
slcfitsio 0.3.8+nosvn-5 is marked for autoremoval from testing on 2021-10-18

It is affected by these RC bugs:
994673: slcfitsio: slcfitsio FTBFS: error: too many decimal points in number
 https://bugs.debian.org/994673



This mail is generated by:
https://salsa.debian.org/release-team/release-tools/-/blob/master/mailer/mail_autoremovals.pl

Autoremoval data is generated by:
https://salsa.debian.org/qa/udd/-/blob/master/udd/testing_autoremovals_gatherer.pl



Processing of libbrahe_1.3.2-9_source.changes

2021-09-27 Thread Debian FTP Masters
libbrahe_1.3.2-9_source.changes uploaded successfully to localhost
along with the files:
  libbrahe_1.3.2-9.dsc
  libbrahe_1.3.2-9.debian.tar.xz

Greetings,

Your Debian queue daemon (running on host usper.debian.org)



libbrahe_1.3.2-9_source.changes ACCEPTED into unstable

2021-09-27 Thread Debian FTP Masters



Accepted:

-BEGIN PGP SIGNED MESSAGE-
Hash: SHA512

Format: 1.8
Date: Mon, 27 Sep 2021 16:29:23 -0700
Source: libbrahe
Architecture: source
Version: 1.3.2-9
Distribution: unstable
Urgency: medium
Maintainer: Debian QA Group 
Changed-By: Vagrant Cascadian 
Closes: 995211
Changes:
 libbrahe (1.3.2-9) unstable; urgency=medium
 .
   * QA upload.
   * libbrahe-dev: Do not install test Makefile (Closes: #995211).
   * debian/control: Update Vcs-Browser and Vcs-Git.
   * debian/control: Set Rules-Requires-Root to "no".
   * debian/changelog: Delete trailing whitespace.
   * debian/rules: Delete boilerplate comments.
   * debian/control: Update to debhelper-compat 13.
   * debian/rules: Add override for dh_missing to only list missing files.
   * debian/control: Delete trailing whitespace.
   * debian/control: Split Build-Depends into multiple lines.
   * Remove Dependency on dh-autoreconf and explicit call to autoreconf in
 debian/rules.
   * debian/control: Drop Build-Depends on autotools-dev.
   * debian/control: Remove quilt from Build-Depends.
   * debian/control: Update Standards-Version to 4.6.0.
   * debian/control: Mark libbrahe-1.3-3 as Multi-Arch: same.
Checksums-Sha1:
 ce1e16c73ce2773f06f76ed20b8d5fcd63446947 1475 libbrahe_1.3.2-9.dsc
 6a0aeccf3df3817a293ff805bc3f4fdef50fdd37 4252 libbrahe_1.3.2-9.debian.tar.xz
Checksums-Sha256:
 2c766344fad8ce849b78f2aa7ed9c56d547797923a854fa25ac37620021d4d90 1475 
libbrahe_1.3.2-9.dsc
 7df43efcb20d8ecb61e945a57fe50cbf1c7e51c42d5862fbcfd48632c8f6cfa7 4252 
libbrahe_1.3.2-9.debian.tar.xz
Files:
 774cf538f930c510f03500907c801d61 1475 libs optional libbrahe_1.3.2-9.dsc
 784a1623d6018df41511d8c845f4c114 4252 libs optional 
libbrahe_1.3.2-9.debian.tar.xz

-BEGIN PGP SIGNATURE-

iIkEARYKADEWIQRlgHNhO/zFx+LkXUXcUY/If5cWqgUCYVJXxBMcdmFncmFudEBk
ZWJpYW4ub3JnAAoJENxRj8h/lxaqNyABAIOgvNDYkWGpYbmQ0a8HuYEbpMgV9OhP
p79ecXEj2r1/AQCytUju4Zq9EwDj/4bs8wZmfZhdBVxdzfUTKZyGEiOABg==
=XqL9
-END PGP SIGNATURE-


Thank you for your contribution to Debian.



Bug#995217: maildirsync: reproducible builds: tarball in examples does not build reproducibly

2021-09-27 Thread Vagrant Cascadian
Source: maildirsync
Severity: normal
Tags: patch
User: reproducible-bui...@lists.alioth.debian.org
Usertags: umask username fileordering
X-Debbugs-Cc: reproducible-b...@lists.alioth.debian.org

The username, uid, group name, gid and umask are embedded in the example
tarball of mailbalance:

  
https://tests.reproducible-builds.org/debian/rb-pkg/unstable/amd64/diffoscope-results/maildirsync.html

  /usr/share/doc/maildirsync/examples/mailbalance-0.2.0.tar.gz

  
drwxr-xr-x···0·pbuilder1··()·pbuilder1··()0·2010-11-01·18:38:55.00·mailbalance-0.2.0/
  vs.
  
drwxrwxr-x···0·pbuilder2··()·pbuilder2··()0·2010-11-01·18:38:55.00·mailbalance-0.2.0/

The attached patch fixes this by instead including the files in the
examples directory directly. The files are not particularly large and
dpkg does various forms of normalization on it.


Thanks for maintaining maildirsync!


live well,
  vagrant
From f3bdf22ca846a2ba42e2f80d42a99e9b004bfc0c Mon Sep 17 00:00:00 2001
From: Vagrant Cascadian 
Date: Tue, 28 Sep 2021 00:35:35 +
Subject: [PATCH] Install mailbalance example directly into examples.

The way the tarball was built embeds various information from the
build environment (username, groupname, uid, gid, umask) and the
ordering of the files was unpredictible.

The tarball only saves a small amount of additional space, so instead
just install the files directly.

https://tests.reproducible-builds.org/debian/issues/different_due_to_umask_issue.html
https://tests.reproducible-builds.org/debian/issues/users_and_groups_in_tarball_issue.html
https://tests.reproducible-builds.org/debian/issues/random_order_in_tarball_issue.html
---
 debian/examples | 1 +
 debian/rules| 3 ---
 2 files changed, 1 insertion(+), 3 deletions(-)

diff --git a/debian/examples b/debian/examples
index e0e9a33..615a8f0 100644
--- a/debian/examples
+++ b/debian/examples
@@ -1 +1,2 @@
 sample.sh
+contrib/mailbalance-0.2.0
diff --git a/debian/rules b/debian/rules
index 34e0cbb..1bdefc4 100755
--- a/debian/rules
+++ b/debian/rules
@@ -11,6 +11,3 @@ execute_after_dh_auto_clean:
 
 execute_after_dh_auto_install:
 	cp maildirsync.pl debian/maildirsync/usr/bin/maildirsync
-
-execute_after_dh_installexamples:
-	cd contrib && tar -cf - mailbalance-0.2.0 | gzip -n -9 > ../debian/maildirsync/usr/share/doc/maildirsync/examples/mailbalance-0.2.0.tar.gz
Index: b/htword/WordBitCompress.cc
===
--- a/htword/WordBitCompress.cc
+++ b/htword/WordBitCompress.cc
@@ -29,7 +29,7 @@
 #include"WordBitCompress.h"
 
 //  HtVector_byte (implementation)
-#define GType byte
+#define GType byte_t
 #define HtVectorGType HtVector_byte
 #include "HtVectorGenericCode.h"
 
@@ -424,13 +424,13 @@
 // **
 
 void 
-BitStream::put_zone(byte *vals,int n,const char *tag)
+BitStream::put_zone(byte_t *vals,int n,const char *tag)
 {
 add_tag(tag);
 for(int i=0;i<(n+7)/8;i++){put_uint(vals[i],TMin(8,n-8*i),NULL);}
 }
 void 
-BitStream::get_zone(byte *vals,int n,const char *tag)
+BitStream::get_zone(byte_t *vals,int n,const char *tag)
 {
 check_tag(tag);
 for(int i=0;i<(n+7)/8;i++){vals[i]=get_uint(TMin(8,n-8*i));}
@@ -699,16 +699,16 @@
 if(all){printf("\n");}
 
 }
-byte *
+byte_t *
 BitStream::get_data()
 {
-byte *res=(byte *)malloc(buff.size());
+byte_t *res=(byte_t *)malloc(buff.size());
 CHECK_MEM(res);
 for(int i=0;imaxv){maxv=v;}
 }
 int nbits=num_bits(maxv);
-if(n>=pow2(NBITS_NVALS)){errr("Compressor::put_fixedbitl(byte *) : overflow: nvals>2^16");}
+if(n>=pow2(NBITS_NVALS)){errr("Compressor::put_fixedbitl(byte_t *) : overflow: nvals>2^16");}
 put_uint(nbits,NBITS_NBITS_CHARVAL,"nbits");
 add_tag("data");
 for(i=0;i=(buff.size()<<3)){errr("BitStream::get reading past end of BitStream!");}
-	byte res=buff[bitpos>>3] & pow2(bitpos & 0x07);
+	byte_t res=buff[bitpos>>3] & pow2(bitpos & 0x07);
 //  	printf("get:res:%d bitpos:%5d/%d buff[%3d]=%x\n",res,bitpos,bitpos%8,bitpos/8,buff[bitpos/8]);
 	bitpos++;
 	return(res);
@@ -139,8 +139,8 @@
 unsigned int get_uint(   int n,const char *tag=(char*)NULL);
 
 // get/put n bits of data stored in vals
-void put_zone(byte *vals,int n,const char *tag);
-void get_zone(byte *vals,int n,const char *tag);
+void put_zone(byte_t *vals,int n,const char *tag);
+void get_zone(byte_t *vals,int n,const char *tag);
 
 // 
 inline void add_tag(const char *tag)
@@ -167,9 +167,9 @@
 int buffsize(){return(buff.size());}
 
 // get a copy of the buffer
-byte *get_data();
+byte_t *get_data();
 // set the buffer from outside data (current buffer must be empty)
-void set_data(const byte *nbuff,int nbits);
+void set_data(const byte_t *nbuff,int nbits);
   
 // use this for reading a BitStream after you have written in it 
 // (generally for debuging)
@@ -211,7 +211,7 @@
 #define NBITS_VAL 32
 // number of bits to code he number of bits used by an unsigned int value
 #define NBITS_NBITS_VAL  5
 // number of bits to code the number of bits used by a byte value
 #define NBITS_NBITS_CHARVAL 4
 
 class Compressor : public BitStream
@@ -240,8 +240,8 @@
 int get_vals(unsigned int **pres,const char *tag=(char*)"BADTAG!");
 
 // compress/decompress an array of bytes (very simple)
-int put_fixedbitl(byte *vals,int n,const char *tag);
-int get_fixedbitl(byte **pres,const char *tag=(char*)"BADTAG!");
+int put_fixedbitl(byte_t *vals,int n,const char *tag);
+int get_fixedbitl(byte_t **pres,const char *tag=(char*)"BADTAG!");
 
 // compress/decompress an array of unsigned ints (very simple)
 void get_fixedbitl(unsigned int *res,int n);
@@ -211,7 +211,7 @@
 // number of bits to code he number of bits used by an unsigned int value
 #define NBITS_NBITS_VAL  5
-// number of bits to code the number of bits used by a byte value
+// number of bits to code the number of bits used by a byte_t value
 #define NBITS_NBITS_CHARVAL 4
 
-- 
2.33.0



signature.asc
Description: PGP signature